/*******************************************************************************
*
* E M B E D D E D   W I Z A R D   P R O J E C T
*
*                                                Copyright (c) TARA Systems GmbH
*                                    written by Paul Banach and Manfred Schweyer
*
********************************************************************************
*
* This software is delivered "as is" and shows the usage of other software
* components. It is provided as an example software which is intended to be
* modified and extended according to particular requirements.
*
* TARA Systems hereby disclaims all warranties and conditions with regard to the
* software, including all implied warranties and conditions of merchantability
* and non-infringement of any third party IPR or other rights which may result
* from the use or the inability to use the software.
*
********************************************************************************
*
* DESCRIPTION:
*   This file is part of the interface (glue layer) between an Embedded Wizard
*   generated UI application and the board support package (BSP) of a dedicated
*   target.
*   This template is responsible to initialize the display hardware of the board
*   and to provide the necessary access to update the display content.
*   The color format of the framebuffer has to correspond to the color format
*   of the Graphics Engine.
*
*   Important: This file is intended to be used as a template. Please adapt the
*   implementation according your particular hardware.
*
*******************************************************************************/

#ifndef EW_BSP_DISPLAY_H
#define EW_BSP_DISPLAY_H


#ifdef __cplusplus
  extern "C"
  {
#endif


/******************************************************************************
* TYPE:
*   XDisplayInfo
*
* DESCRIPTION:
*   The structure XDisplayInfo describes the attributes and current configuration
*   of the display. The interpretation and usage of the members may depend on the
*   underlying system and the selected framebuffer integration scenario.
*
* ELEMENTS:
*   Name           - The Name of the display.
*   FrameBuffer    - Pointer to the framebuffer memory. In case of double-buffering
*     it refers to the first framebuffer (not the currently active front-buffer).
*   DoubleBuffer   - Pointer to the second framebuffer in case of double-buffering.
*   DisplayWidth,
*   DisplayHeight  - Size of the display in pixel.
*   ViewportX,
*   ViewportY      - Origin of the viewport / start position of the GUI.
*   ViewportWidth,
*   ViewportHeight - Size of the viewport / area where the GUI will be drawn.
*   Context        - Optional pointer to a target specific struct.
*
******************************************************************************/
typedef struct
{
  char*             Name;
  void*             FrameBuffer;
  void*             DoubleBuffer;
  int               DisplayWidth;
  int               DisplayHeight;
  int               ViewportX;
  int               ViewportY;
  int               ViewportWidth;
  int               ViewportHeight;
  void*             Context;
} XDisplayInfo;


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayInit
*
* DESCRIPTION:
*   The function EwBspDisplayInit initializes the display hardware and returns
*   the display parameter.
*
* ARGUMENTS:
*   aGuiWidth,
*   aGuiHeight   - Size of the GUI in pixel.
*   aDisplayInfo - Display info data structure.
*
* RETURN VALUE:
*   Returns 1 if successful, 0 otherwise.
*
*******************************************************************************/
int EwBspDisplayInit
(
  int               aGuiWidth,
  int               aGuiHeight,
  XDisplayInfo*     aDisplayInfo
);


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayDone
*
* DESCRIPTION:
*   The function EwBspDisplayDone deinitializes the display hardware.
*
* ARGUMENTS:
*   aDisplayInfo - Display info data structure.
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspDisplayDone
(
  XDisplayInfo*     aDisplayInfo
);


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayUpdate
*
* DESCRIPTION:
*   The function EwBspDisplayUpdate updates the screen content.
*
* ARGUMENTS:
*   aContext - Display context.
*   aArea    - The update area.
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspDisplayUpdate
(
  void* aContext,
  XRect aArea
);


#ifdef __cplusplus
  }
#endif

#endif /* EW_BSP_DISPLAY_H */


/* mli, msy */
